
declare
v_grid_name varchar2(6);
v_grid_id number(14);
v_grid_desc varchar2(40);
v_field_id number(14);
v_field_id_list VARCHAR2(1000);
v_grid_key_fields VARCHAR2(200);
v_dataspy_id number(14);
v_bot_number number(14);
v_field_source_name varchar2(100);
v_field_tag_name varchar2(100);
v_language VARCHAR2(2);
r5boilertexts_exists integer;
r5grid_exists integer;
r5functions_exists integer;
sequence_check varchar2(3);

begin

-------------------------------------------------------------------------------
-- Set custom grid name
-------------------------------------------------------------------------------

v_grid_name := 'AUI002'; 
v_language := '&1';

-------------------------------------------------------------------------------
-- Cleanup existing r5boilertexts
-------------------------------------------------------------------------------

select count(*) into r5boilertexts_exists
from r5boilertexts
where BOT_FUNCTION = v_grid_name
and rownum = 1;

IF r5boilertexts_exists = 1 THEN
	DELETE FROM r5boilertexts where BOT_FUNCTION = v_grid_name;
END IF;

-------------------------------------------------------------------------------
-- Cleanup existing r5grid and related data
-------------------------------------------------------------------------------

select count(*) into r5grid_exists
from r5grid
where GRD_GRIDNAME = v_grid_name
and rownum = 1;

IF r5grid_exists = 1 THEN
	DELETE FROM r5queryfield where DQF_DDSPYID in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
	DELETE FROM r5usegridsysdefault where usd_dataspyid in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
    DELETE FROM R5dddataspy WHERE DDS_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridfield where GFD_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridparam where GDP_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5grid WHERE GRD_GRIDNAME = v_grid_name;
END IF;


-------------------------------------------------------------------------------
-- Cleanup existing r5functions
-------------------------------------------------------------------------------

select count(*) into r5functions_exists
from r5functions
where FUN_CODE = v_grid_name
and rownum = 1;

IF r5functions_exists = 1 THEN
  DELETE FROM R5EXTMENULANG WHERE EML_EXTMENU IN (SELECT EMN_CODE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name);
  DELETE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name;
  DELETE FROM r5functions where FUN_CODE = v_grid_name;
END IF;


-------------------------------------------------------------------------------
--Insert r5functions
-------------------------------------------------------------------------------
INSERT INTO R5FUNCTIONS (FUN_CODE,FUN_DESC,FUN_CLASS,FUN_SUBTYPE,FUN_FILE,FUN_PUBLIC,FUN_SELECT,FUN_BACKGROUND,FUN_APPLICATION,FUN_DIRSEL,FUN_SYSTEM,FUN_DISPLAYAP,FUN_DISPLAYFT,FUN_POPUPAP,FUN_POPUPFT,FUN_DESCCHANGED,FUN_CLASS_ORG,FUN_RS,FUN_LST,FUN_HDR,FUN_EWSREPORT,FUN_PRDDATASRC,FUN_EWSURLNEW,FUN_REPDISABLED,FUN_ADVREPT,FUN_MEKEY,FUN_EWSBTN)
 VALUES (v_grid_name,'Store Bin Stock (AM)','WEBD','M','R5MENU','-','?','-','BSUGRD','-','+','-','+','-','-','-','*','-','+','-','-','-','-','-','-','YN','-');

-------------------------------------------------------------------------------
-- Insert r5grid
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_grid_id, 'GRD', '1', sequence_check);
INSERT INTO R5GRID (GRD_DESC,GRD_GRIDID,GRD_BASEQUERY,GRD_GRIDNAME,GRD_BOTFUNCTION,GRD_PORTLETFLAG,GRD_TAB,GRD_GRIDTYPE,GRD_OPTIMIZERON,GRD_DISTINCT,GRD_COMPLEX,GRD_ACTIVE,GRD_NOSCREENDESIGNER)
 VALUES ('Store Bin Stock (AM)',v_grid_id,'FROM r5binstock, r5objects, r5stores,r5parts WHERE 
obj_part (+) = bis_part
AND          obj_part_org (+) = bis_part_org
AND          obj_store (+) = bis_store
AND          obj_bin (+) = bis_bin
AND          obj_lot (+) = bis_lot
AND          ( obj_rstatus IS NULL OR obj_rstatus IN (''B'', ''C'', ''CRR'') )
AND          str_code = bis_store
AND          par_code=bis_part  
AND          par_org=bis_part_org',v_grid_name,v_grid_name,'-','+',2,'-','-','-','+','-');

-------------------------------------------------------------------------------
-- Insert r5dddataspy
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_dataspy_id, 'DDS', '1', sequence_check);
INSERT INTO R5DDDATASPY (DDS_DDSPYNAME,DDS_DDSPYID,DDS_SCOPE,DDS_ORGANIZATION,DDS_CREATEDSTAMP,DDS_FILTERSTRXML,DDS_SORTSTRXML,DDS_OWNER,DDS_GRIDID,DDS_TYPE,DDS_DEFAULTFLAG,DDS_CLIENTROWS,DDS_BOTNAME,DDS_SECURITYDATASPY,DDS_MEKEY)
 VALUES ('All Records',v_dataspy_id,'-','*',sysdate,'<FILTERABLE />','<SORTABLE />','R5',v_grid_id,'SD','+',30,'DSNAME','-','YY');

-------------------------------------------------------------------------------
-- Insert the three base r5boilertexts
-- Note: You must also insert a r5boilertext record for each "grid field" (see below)
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,1,100,0,0,v_language,'List View','TB','1','LST','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,2,100,0,0,v_language,'Store Bin Stock (AM)','F','1','UDG_HDRLABEL','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,3,100,0,0,v_language,'All Records','F','1','DSNAME','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,4,100,0,0,v_language,'bisqtyuom','F','1','bisqtyuom','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,5,100,0,0,v_language,'storeorganization','F','1','storeorganization','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,6,100,0,0,v_language,'bisassetid','F','1','bisassetid','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,7,100,0,0,v_language,'bisstore','F','1','bisstore','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,8,100,0,0,v_language,'partdescription','F','1','partdescription','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,9,100,0,0,v_language,'storedesc','F','1','storedesc','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,10,100,0,0,v_language,'bisbin','F','1','bisbin','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,11,100,0,0,v_language,'bislot','F','1','bislot','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,14,100,0,0,v_language,'partcode','F','1','partcode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,15,100,0,0,v_language,'partorg','F','1','partorg','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,16,100,0,0,v_language,'obj_org','F','1','obj_org','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,17,100,0,0,v_language,'bisqty','F','1','bisqty','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,18,100,0,0,v_language,'repairquantity','F','1','repairquantity','10000',sysdate,'-');

-------------------------------------------------------------------------------
-- Copy the R5BOILERTEXTS for each of the languages in the R5LANGINST
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED)
SELECT BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,LIN_CODE,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED
FROM R5BOILERTEXTS, R5LANGINST
WHERE
BOT_LANG = v_language AND BOT_FUNCTION = v_grid_name AND lin_code <> v_language;

-------------------------------------------------------------------------------
-- Insert r5ddfield, r5gridfield, r5queryfield for each grid field
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'PAR_UOM','MIXVARCHAR','LVUOMS;gridtagname=UOMCODE','R5PARTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,4,'TEXT','bisqtyuom','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',1,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'STR_ORG','VARCHAR','','R5MP2WAREHOUSE_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,5,'TEXT','storeorganization','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',2,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'obj_code','VARCHAR','','R5MP2NPCDT_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,6,'TEXT','bisassetid','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',3,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'bis_store','VARCHAR','','R5MP2STOCK_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,7,'TEXT','bisstore','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',4,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'r5o7.o7get_desc(:parameter.language,''PART'',bis_part||''#''||bis_part_org,'''', '''')','MIXVARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,8,'TEXT','partdescription','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',5,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'r5o7.o7get_desc(:parameter.language,''STOR'',str_code||''#''||str_org,'''', '''')','VARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,9,'TEXT','storedesc','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',6,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'bis_bin','VARCHAR','','R5MP2STOCK_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,10,'TEXT','bisbin','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',7,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'bis_lot','VARCHAR','','R5MP2STOCK_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,11,'TEXT','bislot','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',8,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'bis_part','VARCHAR','','R5MP2STOCK_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,14,'TEXT','partcode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',9,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'bis_part_org','VARCHAR','','R5MP2STOCK_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,15,'TEXT','partorg','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',10,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'obj_org','VARCHAR','','R5MP2NPCDT_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,16,'TEXT','obj_org','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',11,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'CASE WHEN obj_code is null THEN NVL(bis_qty,0) ELSE CASE WHEN obj_rstatus=''CRR'' THEN 0 ELSE 1 END END','DECIMAL','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,17,'TEXT','bisqty','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',12,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'CASE WHEN obj_code is null THEN NVL(bis_repairqty,0) ELSE CASE WHEN obj_rstatus=''CRR'' THEN 1 ELSE 0 END END','DECIMAL','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,18,'TEXT','repairquantity','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',13,'LIST');


-------------------------------------------------------------------------------
-- Insert r5gridparam
-------------------------------------------------------------------------------
INSERT INTO R5GRIDPARAM (GDP_GRIDID,GDP_PARAM)
 VALUES (v_grid_id,'parameter.language');


-------------------------------------------------------------------------------
-- Setup field keys on r5grid
-------------------------------------------------------------------------------

update r5grid set 
grd_keyfields = v_grid_key_fields, 
grd_filterablelist = v_field_id_list,
grd_sortablelist = v_field_id_list,
grd_displayablelist = v_field_id_list
where grd_gridid = v_grid_id;

commit;

end;

/
