
declare
v_grid_name varchar2(6);
v_grid_id number(14);
v_grid_desc varchar2(40);
v_field_id number(14);
v_field_id_list VARCHAR2(1000);
v_grid_key_fields VARCHAR2(200);
v_dataspy_id number(14);
v_bot_number number(14);
v_field_source_name varchar2(100);
v_field_tag_name varchar2(100);
v_language VARCHAR2(2);
r5boilertexts_exists integer;
r5grid_exists integer;
r5functions_exists integer;
sequence_check varchar2(3);

begin

-------------------------------------------------------------------------------
-- Set custom grid name
-------------------------------------------------------------------------------

v_grid_name := 'WUSCHD'; 
v_language := '&1';

-------------------------------------------------------------------------------
-- Cleanup existing r5boilertexts
-------------------------------------------------------------------------------

select count(*) into r5boilertexts_exists
from r5boilertexts
where BOT_FUNCTION = v_grid_name
and rownum = 1;

IF r5boilertexts_exists = 1 THEN
	DELETE FROM r5boilertexts where BOT_FUNCTION = v_grid_name;
END IF;

-------------------------------------------------------------------------------
-- Cleanup existing r5grid and related data
-------------------------------------------------------------------------------

select count(*) into r5grid_exists
from r5grid
where GRD_GRIDNAME = v_grid_name
and rownum = 1;

IF r5grid_exists = 1 THEN
	DELETE FROM r5queryfield where DQF_DDSPYID in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
	DELETE FROM r5usegridsysdefault where usd_dataspyid in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
    DELETE FROM R5dddataspy WHERE DDS_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridfield where GFD_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridparam where GDP_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5grid WHERE GRD_GRIDNAME = v_grid_name;
END IF;


-------------------------------------------------------------------------------
-- Cleanup existing r5functions
-------------------------------------------------------------------------------

select count(*) into r5functions_exists
from r5functions
where FUN_CODE = v_grid_name
and rownum = 1;

IF r5functions_exists = 1 THEN
  DELETE FROM R5EXTMENULANG WHERE EML_EXTMENU IN (SELECT EMN_CODE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name);
  DELETE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name;
  DELETE FROM r5functions where FUN_CODE = v_grid_name;
END IF;


-------------------------------------------------------------------------------
--Insert r5functions
-------------------------------------------------------------------------------
INSERT INTO R5FUNCTIONS (FUN_CODE,FUN_DESC,FUN_CLASS,FUN_SUBTYPE,FUN_FILE,FUN_PUBLIC,FUN_SELECT,FUN_BACKGROUND,FUN_DIRSEL,FUN_SYSTEM,FUN_DISPLAYAP,FUN_DISPLAYFT,FUN_POPUPAP,FUN_POPUPFT,FUN_DESCCHANGED,FUN_CLASS_ORG,FUN_RS,FUN_LST,FUN_HDR,FUN_EWSREPORT,FUN_PRDDATASRC,FUN_EWSURLNEW,FUN_REPDISABLED,FUN_ADVREPT,FUN_MEKEY,FUN_EWSBTN)
 VALUES (v_grid_name,'Scheduled Labor (AM)','WEBD','M','R5MENU','-','?','-','-','+','-','+','-','-','-','*','-','+','-','-','-','-','-','-','YN','-');

-------------------------------------------------------------------------------
-- Insert r5grid
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_grid_id, 'GRD', '1', sequence_check);
INSERT INTO R5GRID (GRD_DESC,GRD_GRIDID,GRD_BASEQUERY,GRD_GRIDNAME,GRD_BOTFUNCTION,GRD_PORTLETFLAG,GRD_TAB,GRD_GRIDTYPE,GRD_OPTIMIZERON,GRD_DISTINCT,GRD_COMPLEX,GRD_ACTIVE,GRD_NOSCREENDESIGNER)
 VALUES ('Scheduled Labor (AM)',v_grid_id,'FROM r5actschedules s,r5activities a,r5events e,r5ucodes u
    WHERE e.evt_code = a.act_event
    AND a.act_event = s.acs_event
    AND a.act_act = s.acs_activity
    AND e.evt_rtype IN (''JOB'', ''PPM'')
    AND u.uco_rentity = ''JBTP''
    and u.uco_code=e.evt_jobtype
    AND u.uco_rcode IN ( ''*'', ''BR'', ''ST'', ''PM'', ''CAL'' ,''RP'', ''MEC'')
    AND e.evt_rstatus = ''R''',v_grid_name,v_grid_name,'-','+',2,'-','-','-','+','-');

-------------------------------------------------------------------------------
-- Insert r5dddataspy
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_dataspy_id, 'DDS', '1', sequence_check);
INSERT INTO R5DDDATASPY (DDS_DDSPYNAME,DDS_DDSPYID,DDS_SCOPE,DDS_ORGANIZATION,DDS_CREATEDSTAMP,DDS_FILTERSTRXML,DDS_SORTSTRXML,DDS_OWNER,DDS_GRIDID,DDS_TYPE,DDS_DEFAULTFLAG,DDS_CLIENTROWS,DDS_BOTNAME,DDS_SECURITYDATASPY,DDS_MEKEY)
 VALUES ('All Records',v_dataspy_id,'-','*',sysdate,'<FILTERABLE />','<SORTABLE><SORT_ELEMENT ALIAS_NAME="evt_created" SEQNUM="1" TYPE="ASC"/><SORT_ELEMENT ALIAS_NAME="acs_activity" SEQNUM="2" TYPE="ASC"/><SORT_ELEMENT ALIAS_NAME="acs_code" SEQNUM="3" TYPE="ASC"/></SORTABLE>','R5',v_grid_id,'SD','+',30,'DSNAME','-','YY');

-------------------------------------------------------------------------------
-- Insert the three base r5boilertexts
-- Note: You must also insert a r5boilertext record for each "grid field" (see below)
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,1,100,0,0,v_language,'List View','TB','1','LST','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,2,100,0,0,v_language,'Scheduled Labor (AM)','F','1','UDG_HDRLABEL','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,3,100,0,0,v_language,'All Records','F','1','DSNAME','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,4,100,0,0,v_language,'acs_code','F','1','acs_code','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,5,100,0,0,v_language,'acs_event','F','1','acs_event','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,6,100,0,0,v_language,'acs_activity','F','1','acs_activity','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,7,100,0,0,v_language,'acs_mrc','F','1','acs_mrc','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,8,100,0,0,v_language,'acs_sched','F','1','acs_sched','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,9,100,0,0,v_language,'acs_responsible','F','1','acs_responsible','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,10,100,0,0,v_language,'acs_hours','F','1','acs_hours','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,11,100,0,0,v_language,'evt_org','F','1','evt_org','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,12,100,0,0,v_language,'acs_updated','F','1','acs_updated','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,13,100,0,0,v_language,'acs_updatecount','F','1','acs_updatecount','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,14,100,0,0,v_language,'evt_created','F','1','evt_created','10000',sysdate,'-');

-------------------------------------------------------------------------------
-- Copy the R5BOILERTEXTS for each of the languages in the R5LANGINST
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED)
SELECT BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,LIN_CODE,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED
FROM R5BOILERTEXTS, R5LANGINST
WHERE
BOT_LANG = v_language AND BOT_FUNCTION = v_grid_name AND lin_code <> v_language;

-------------------------------------------------------------------------------
-- Insert r5ddfield, r5gridfield, r5queryfield for each grid field
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_code','VARCHAR','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,4,'TEXT','acs_code','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',1,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_event','VARCHAR','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,5,'TEXT','acs_event','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',2,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_activity','NUMBER','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,6,'TEXT','acs_activity','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',3,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_mrc','VARCHAR','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,7,'TEXT','acs_mrc','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',4,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_sched','DATE','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,8,'TEXT','acs_sched','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',5,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_responsible','VARCHAR','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,9,'TEXT','acs_responsible','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',6,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_hours','DECIMAL','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,10,'TEXT','acs_hours','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',7,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'evt_org','VARCHAR','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,11,'TEXT','evt_org','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',8,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_updated','DATETIME','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,12,'TEXT','acs_updated','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',9,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'acs_updatecount','NUMBER','R5ACTSCHEDULES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,13,'TEXT','acs_updatecount','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',10,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'evt_created','DATETIME','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,14,'TEXT','evt_created','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',11,'LIST');


-------------------------------------------------------------------------------
-- Insert r5gridparam
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- Setup field keys on r5grid
-------------------------------------------------------------------------------

update r5grid set 
grd_keyfields = v_grid_key_fields, 
grd_filterablelist = v_field_id_list,
grd_sortablelist = v_field_id_list,
grd_displayablelist = v_field_id_list
where grd_gridid = v_grid_id;

commit;

end;

/
